@@ -184,11 +184,11 @@ class GUI:
     def about_page(self, widget):
         aboutdialog = gtk.AboutDialog()        
         aboutdialog.set_name("CON900")
-        aboutdialog.set_version("0.0.9-2")
+        aboutdialog.set_version("0.0.9-3")
         aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
         aboutdialog.set_license("GNU LGPL 2.1")
         aboutdialog.set_website("humblecon900.garage.maemo.org")
-        aboutdialog.set_authors(["humble-for CON900.","JorgeFX-for OptimizeN900."])
+        aboutdialog.set_authors(["humble-for CON900.","JorgeFX-for OptimizeN900.","and a special thanks to ivgalvez"])
 
         aboutdialog.run()
         aboutdialog.hide()
